# Fuse Assignment Grader

![Python](https://img.shields.io/badge/Python-v^3.8-blue.svg?logo=python&longCache=true&logoColor=white&colorB=5e81ac&style=flat-square&colorA=4c566a)
![GitHub Last Commit](https://img.shields.io/github/last-commit/google/skia.svg?style=flat-square&colorA=4c566a&colorB=a3be8c)
[![latest package](https://img.shields.io/github/v/release/Anyesh/fusegrader?label=latest%20release)](https://github.com/Anyesh/fusegrader/releases)
